@@ -332,9 +332,7 @@ ORBit_get_union_tag(CORBA_TypeCode union_tc,
     else if(union_tc->default_index >= 0)
 	return union_tc->subtypes[union_tc->default_index];
     else {
-	g_error("Failed to find a matching union case! discrim_val = %ld",
-		discrim_val);
-	return NULL; /* notreached */
+	return TC_null;
     }
 }
 
