@@ -207,37 +207,32 @@ ORBit_DynAny_items_from_any(CORBA_TypeCode type,
 		CORBA_Object_duplicate((CORBA_Object)type, ev);
 
 	switch(type->kind) {
-	default:
-		CORBA_Object_release((CORBA_Object)cur->tc, ev);
-		g_free(cur);
-		cur = NULL;
-		break;
-	CORBA_tk_short:
-	CORBA_tk_ushort:
+	case CORBA_tk_short:
+ 	case CORBA_tk_ushort:
 		memcpy(cur->u.data, *value, sizeof(CORBA_short));
 		*value += sizeof(CORBA_short);
 		break;
-	CORBA_tk_long:
-	CORBA_tk_ulong:
-	CORBA_tk_enum:
+	case CORBA_tk_long:
+	case CORBA_tk_ulong:
+	case CORBA_tk_enum:
 		memcpy(cur->u.data, *value, sizeof(CORBA_long));
 		*value += sizeof(CORBA_long);
 		break;
-	CORBA_tk_float:
+	case CORBA_tk_float:
 		memcpy(cur->u.data, *value, sizeof(CORBA_float));
 		*value += sizeof(CORBA_float);
 		break;
-	CORBA_tk_double:
+ 	case CORBA_tk_double:
 		memcpy(cur->u.data, *value, sizeof(CORBA_double));
 		*value += sizeof(CORBA_double);
 		break;
-	CORBA_tk_boolean:
-	CORBA_tk_char:
-	CORBA_tk_octet:
+	case CORBA_tk_boolean:
+	case CORBA_tk_char:
+	case CORBA_tk_octet:
 		memcpy(cur->u.data, *value, sizeof(CORBA_octet));
 		*value += sizeof(CORBA_octet);
 		break;
-	CORBA_tk_any:
+	case CORBA_tk_any:
 		{
 			CORBA_any *anyval;
 			gpointer ptmp;
@@ -250,13 +245,13 @@ ORBit_DynAny_items_from_any(CORBA_TypeCode type,
 			*value += sizeof(CORBA_any);
 		}
 		break;
-	CORBA_tk_TypeCode:
-	CORBA_tk_objref:
+	case CORBA_tk_TypeCode:
+	case CORBA_tk_objref:
 		memcpy(cur->u.data, *value, sizeof(CORBA_Object));
 		CORBA_Object_duplicate((CORBA_Object)cur->u.data, ev);
 		*value += sizeof(CORBA_Object);
 		break;
-	CORBA_tk_Principal:
+	case CORBA_tk_Principal:
 		{
 			/* aka sequence_octet, oh well */
 			CORBA_Principal *prtmp;
@@ -272,7 +267,7 @@ ORBit_DynAny_items_from_any(CORBA_TypeCode type,
 			*value += sizeof(CORBA_Principal);
 		}
 		break;
- 	CORBA_tk_struct:
+ 	case CORBA_tk_struct:
 		*value = ALIGN_ADDRESS(*value, ALIGNOF_CORBA_STRUCT);
 		for(i = 0; i < type->sub_parts; i++) {
 			*value = ALIGN_ADDRESS(*value,
@@ -285,7 +280,7 @@ ORBit_DynAny_items_from_any(CORBA_TypeCode type,
 						   sub);
 		}
 		break;
-	CORBA_tk_union:
+	case CORBA_tk_union:
 		{
 			CORBA_TypeCode data_tc;
 
@@ -297,7 +292,7 @@ ORBit_DynAny_items_from_any(CORBA_TypeCode type,
 				ORBit_DynAny_items_from_any(type->discriminator,
 							    value, ev);
 
-			data_tc = ORBit_get_union_tag(type, *value);
+			data_tc = ORBit_get_union_tag(type, (gpointer *)value);
 
 			*value = ALIGN_ADDRESS(*value,
 					       ORBit_find_alignment(data_tc));
@@ -306,35 +301,40 @@ ORBit_DynAny_items_from_any(CORBA_TypeCode type,
 							    value, ev);
 		}
 		break;
-	CORBA_tk_string:
+	case CORBA_tk_string:
 		cur->u.sub = CORBA_string_dup(*(CORBA_char **)*value);
 		*value += sizeof(CORBA_char *);
 		break;
-	CORBA_tk_sequence:
+	case CORBA_tk_sequence:
 #ifdef FINISH_OFF_HERE_YOU_MORON
 		for(i = 0; i < 
 		cur->u.sub
 #endif
 		break;
-	CORBA_tk_array:
+	case CORBA_tk_array:
 		break;
-	CORBA_tk_alias:
+	case CORBA_tk_alias:
 		break;
-	CORBA_tk_except:
+	case CORBA_tk_except:
 		break;
-	CORBA_tk_longlong:
+	case CORBA_tk_longlong:
 		break;
-	CORBA_tk_ulonglong:
+	case CORBA_tk_ulonglong:
 		break;
-	CORBA_tk_longdouble:
+	case CORBA_tk_longdouble:
 		break;
-	CORBA_tk_wchar:
+	case CORBA_tk_wchar:
 		break;
-	CORBA_tk_wstring:
+	case CORBA_tk_wstring:
 		break;
-	CORBA_tk_fixed:
+	case CORBA_tk_fixed:
 		break;
-	CORBA_tk_recursive:
+	case CORBA_tk_recursive:
+		break;
+	default:
+		CORBA_Object_release((CORBA_Object)cur->tc, ev);
+		g_free(cur);
+		cur = NULL;
 		break;
 	}
 
