@@ -358,16 +358,16 @@ void ORBit_set_default_principal(CORBA_Principal *principal)
 }
 
 CORBA_unsigned_long ORBit_class_assignment_counter = 0;
+GHashTable *ORBit_class_assignments = NULL;
 
 /* XXX not thread-safe */
 CORBA_unsigned_long
 ORBit_register_class(const PortableServer_ClassInfo *class_info)
 {
-	static GHashTable *class_assignments = NULL;
 	CORBA_unsigned_long retval;
 
-	if(!class_assignments)
-		class_assignments = g_hash_table_new(g_str_hash, g_str_equal);
+	if(!ORBit_class_assignments)
+		ORBit_class_assignments = g_hash_table_new(g_str_hash, g_str_equal);
 
 	/* This needs to be pre-increment - we don't want to give out
 	   classid 0, because (a) that is reserved for the base Object class
@@ -375,7 +375,7 @@ ORBit_register_class(const PortableServer_ClassInfo *class_info)
 	   storing their ID == 0 */
 	retval = ++ORBit_class_assignment_counter;
 
-	g_hash_table_insert(class_assignments, (gpointer)class_info->class_name,
+	g_hash_table_insert(ORBit_class_assignments, (gpointer)class_info->class_name,
 			    GINT_TO_POINTER(retval));
 
 	return retval;
