@@ -205,6 +205,8 @@ PortableServer_POAManager_activate(PortableServer_POAManager obj,
 
 		g_slist_foreach(todo, (GFunc)ORBit_POA_handle_request,
 				curpoa);
+		g_slist_foreach(todo, (GFunc)giop_recv_buffer_unuse,
+				NULL);
 
 		g_slist_free(todo);
 	}
