@@ -53,6 +53,7 @@ ORBit_handle_incoming_request(GIOPRecvBuffer *recv_buffer)
 	PortableServer_POA poa;
 	GIOPConnection *connection;
 	ORBit_MessageValidationResult mvr;
+	gboolean do_unuse = TRUE;
 
 	g_assert(recv_buffer);
 
@@ -85,18 +86,19 @@ ORBit_handle_incoming_request(GIOPRecvBuffer *recv_buffer)
 						 recv_buffer);
 			
 		if(poa)
-			ORBit_POA_handle_request(recv_buffer, poa);
+			do_unuse = ORBit_POA_handle_request(recv_buffer, poa);
 		else
 			g_warning("No POA found for operation %s [%d]",
 				  recv_buffer->message.u.request.operation,
 				  recv_buffer->message.u.request.request_id);
 	} else {
-		g_warning("Request %s, ID %d was rejected!",
+		g_warning("Request %s, ID %d was rejected by the authentication mechanism!",
 			  recv_buffer->message.u.request.operation,
 			  recv_buffer->message.u.request.request_id);
 	}
 
-	giop_recv_buffer_unuse(recv_buffer);
+	if(do_unuse)
+		giop_recv_buffer_unuse(recv_buffer);
 }
 
 static void
