@@ -703,8 +703,10 @@ impl_CosNaming_NamingContext_list(impl_POA_CosNaming_NamingContext * servant,
 
   if(how_many > 0) {
     *bl = n_names_into_bindinglist(&itemlist, MIN(how_many, g_hash_table_size(servant->names)));
-  } else
-    *bl = NULL;
+  } else {
+    *bl = CosNaming_BindingList__alloc();
+    (*bl)->_length = 0;
+  }
     
   if(itemlist) {
     impl_POA_CosNaming_BindingIterator *newservant;
